/// <reference types="node" />
import { LightningType, TimeDisplayType, WeatherType } from "./types";
export declare class DivoomTimeBoxEvoProtocol {
    private PREFIX;
    private SUFFIX;
    private _message;
    private _length;
    private _crc;
    private _fullMessage;
    private _gifFrame;
    private _setMessage;
    private _queueMessage;
    private _setCRC;
    private _string2BinBuffer;
    private _boolean2HexString;
    private _number2HexString;
    private _color2HexString;
    private _brightness2HexString;
    /**
     * Generates the appropriate message to display the Time Channel on the Divoom Timebox Evo
     * @param type type of time to display:
     * @param color the color to display, can be of any type supported by [TinyColor]
     * @param showTime show the time?
     * @param showWeather show the weather?
     * @param showTemp show the temperature?
     * @param showCalendar show the calendar?
     */
    displayTimePackage(type?: TimeDisplayType, color?: any, showTime?: boolean, showWeather?: boolean, showTemp?: boolean, showCalendar?: boolean): void;
    /**
     * Generates the appropriate message to display the Lightning Channel on the Divoom Timebox Evo
     * @param type type of lightning you want to display
     * @param color the color to display, can be of any type supported by [TinyColor]
     * @param brightness brightness `0` - `100` range
     * @param power if `false`, the display is turned off
     */
    displayLightningPackage(type?: LightningType, color?: any, brightness?: number, power?: boolean): void;
    /**
     * Generates the appropriate message to display the Cloud Channel
     */
    displayCloudPackage(): void;
    /**
     * Generates the appropriate message to display the VJ Effects Channel
     * @param type type of Effect to display
     */
    displayVJEffectsPackage(type?: number): void;
    /**
     * Generates the appropriate message to display the scoreboard
     * @param red the score for the red player (0 - 999)
     * @param blue the score for the blue player (0 - 999)
     */
    displayScoreBoardPackage(red?: number, blue?: number): void;
    /**
     * Generates the appropriate message to set the temperature and the weather
     * @param temp temperature to set (`-127 <= temp <= 128`)
     * @param weatherType type of weather to set
     */
    setTempAndWeatherPackage(temp: number, weatherType: WeatherType): void;
    /**
     * Generates the appropiate message to set the brightness on the Timebox
     * @param brightness brightness (`0 - 100`) if `in_min` or `in_max` are undefined, else `in_min <= brightness <= in_max`
     * @param in_min
     * @param in_max
     */
    setBrightness(brightness: number, in_min?: number, in_max?: number): void;
    /**
     * Generates the full message, properly split which will be ready to be send to Divoom
     * @param msg the string or Buffer that you want to encode before sending to Divoom
     */
    createRAWPackage(msg: string | Buffer): void;
    /**
     * @returns The an array of strings of all the messages which should be sent
     */
    getDivoomMessageArray(): string[] | undefined;
    getDivoomMessageString(): string | undefined;
    /**
     * @returns The an array of messages as a Binary Buffer ready to be sent
     */
    getDivoomBinaryBuffer(): Buffer[] | undefined;
    /**
     * Generates the appropriate message to display an animation or an image on the Timebox
     * @param input a path to an image or a Buffer representing an image file
     * @returns A promise which resolves when the processing is done
     */
    displayAnimation(input: Buffer | string): Promise<DivoomTimeBoxEvoProtocol>;
    /**
     * This function generates the message when the a static image is used
     * @param input a Buffer representing an image file
     * @returns A promise which resolves when the processing is done
     */
    private _displayImage;
    /**
     * This function generates the message when the a static image is used
     * @param input Buffer representing an image file
     * @returns A promise which resolves when the processing is done
     */
    private _displayAnimationFromGIF;
}
